Changelog
=========

v2022.7.18
----------
* use flit for packaging
* add Stieltjes transform
* add Laplace transform
* add Hankel transform

v2022.7.15
----------
* module for standard integral transforms

v2022.7.13
----------
* initial version
